@@ -69,16 +69,16 @@ def compute_entropy(params, tail):
 
 
 
-def format_parameters_for_export(data, params, tail):
+def format_parameters_for_export(data, params, tail, K):
     res = {k : 0 for k in data.keys()}
     theoretical_num_clones = get_theo_clones(data)
     clones_count = get_clones_counts(theoretical_num_clones)
     for i, k in enumerate(res):
-        res[k] = format_parameters_for_export_aux(data, params,k, i, theoretical_num_clones, clones_count, tail)
+        res[k] = format_parameters_for_export_aux(data, params,k, i, theoretical_num_clones, clones_count, tail, K)
     return res
 
 
-def format_parameters_for_export_aux(data, params,k, i, theo_clones, counts_clone, tail):
+def format_parameters_for_export_aux(data, params,k, i, theo_clones, counts_clone, tail, K):
 
     j = counts_clone[i]
     if theo_clones[i] == 2:
@@ -95,7 +95,7 @@ def format_parameters_for_export_aux(data, params,k, i, theo_clones, counts_clon
         mixture_weights = np.insert(mixture_weights, 0, tail_weights[0])
 
 
-    ca, order_vec = rename_clusters(np.argmax(params["cluster_probs"][k].detach().numpy(), axis = 0), tail, theo_clones[i])
+    ca, order_vec = rename_clusters(np.argmax(params["cluster_probs"][k].detach().numpy(), axis = 0), tail, theo_clones[i], K)
 
     res = {"cluster_probs" : params["cluster_probs"][k].detach().numpy(),
            "cluster_assignments" : ca,
@@ -112,27 +112,28 @@ def format_parameters_for_export_aux(data, params,k, i, theo_clones, counts_clon
     return res
 
 
-def rename_clusters(x,tail, theo_c):
+def rename_clusters(x,tail, theo_c, K):
+
     res = np.empty(len(x), dtype='object')
-    uniq_clusts = np.unique(x)
     base_idx = 0
     clonal_num = 1
     subclonal_num = 1
-    order_vec = np.array([],dtype='object' )
+    order_vec = np.array([],dtype='object')
+
     ###  IDENTIFY TAIL MUTATIONS ###
     if tail == 1:
         res[x == 0] = "Tail"
-        np.append(order_vec,"Tail")
+        np.append(order_vec, "Tail")
         base_idx += 1
 
     ### IDENTIFY CLONAL MUTATIONS ###
     for i in range(base_idx, base_idx + theo_c):
         res[x == i] = "C" + str(clonal_num)
-        np.append(order_vec,"C" + str(clonal_num))
+        np.append(order_vec, "C" + str(clonal_num))
         clonal_num += 1
 
     ### IDENTIFY SUBCLONAL MUTATIONS ###
-    for i in range(base_idx + theo_c,len(uniq_clusts)):
+    for i in range(base_idx + theo_c,base_idx + theo_c + K):
         res[x == i] = "S" + str(subclonal_num)
         np.append(order_vec, "S" + str(subclonal_num))
         subclonal_num += 1
